import { SerializedDocument } from '../document';
import { Plugin } from '../plugin';
export declare enum ActionType {
    Insert = "Insert",
    Remove = "Remove",
    Change = "Change",
    Focus = "Focus",
    Undo = "Undo",
    Redo = "Redo",
    Persist = "Persist",
    ResetHistory = "ResetHistory"
}
export declare enum ActionCommitType {
    ForceCommit = "ForceCommit"
}
export declare function reducer(state: BaseState | State, action: Action): State;
export interface BaseState {
    defaultPlugin: PluginType;
    plugins: Record<PluginType, Plugin<any>>;
    documents: Record<string, PluginState>;
    focus?: string;
}
export interface State extends BaseState {
    history: {
        initialState: BaseState | State;
        actions: Undoable[][];
        redoStack: Undoable[][];
        pending: number;
    };
}
export declare function hasHistory(state: BaseState | State): state is State;
export declare type Undoable = (InsertAction | ChangeAction | RemoveAction) & {
    commit?: ActionCommitType;
};
export declare type Action = Undoable | FocusAction | UndoAction | RedoAction | PersistAction | ResetHistoryAction;
declare type PluginType = string;
export interface InsertAction {
    type: ActionType.Insert;
    payload: {
        id: string;
    } & Partial<PluginState>;
}
export interface ChangeAction<S = unknown> {
    type: ActionType.Change;
    payload: {
        id: string;
        state: (state: S) => S;
    };
}
export interface RemoveAction {
    type: ActionType.Remove;
    payload: string;
}
export interface FocusAction {
    type: ActionType.Focus;
    payload: string;
}
export interface UndoAction {
    type: ActionType.Undo;
}
export interface RedoAction {
    type: ActionType.Redo;
}
export interface PersistAction {
    type: ActionType.Persist;
}
export interface ResetHistoryAction {
    type: ActionType.ResetHistory;
}
export interface PluginState {
    plugin: PluginType;
    state?: unknown;
}
/** Selectors */
export declare function getDocuments(state: State): Record<string, PluginState>;
export declare function getDocument(state: State, id: string): PluginState | null;
export declare function getPlugin(state: State, type: string): Plugin<any> | null;
export declare function getDefaultPlugin(state: State): PluginType;
export declare function getPlugins<K extends string = string>(state: State): Record<K, Plugin<any>>;
export declare function isFocused(state: State, id: string): boolean;
export declare function hasPendingChanges(state: State): boolean;
export declare function serializeDocument(state: State, id: string): SerializedDocument | null;
export {};
//# sourceMappingURL=reducer.d.ts.map